@@ -1,7 +1,7 @@
 package Business::Inventory::Valuation;
 
 our $DATE = '2018-03-15'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -36,7 +36,12 @@ sub buy {
     die "Units must be > 0" unless $units > 0;
     die "Unit price must be >= 0" unless $unit_price >= 0;
 
-    push @{ $self->{_inventory} }, [$units, $unit_price];
+    if (@{ $self->{_inventory} } && $self->{_inventory}[-1][1] == $unit_price) {
+        $self->{_inventory}[-1][0] += $units;
+    } else {
+        push @{ $self->{_inventory} }, [$units, $unit_price];
+    }
+
     if (@{ $self->{_inventory} } == 1) {
         $self->{_units}    = $units;
         $self->{_average_purchase_price} = $unit_price;
@@ -149,7 +154,7 @@ Business::Inventory::Valuation - Calculate inventory value/unit price (using LIF
 
 =head1 VERSION
 
-This document describes version 0.002 of Business::Inventory::Valuation (from Perl distribution Business-Inventory-Valuation), released on 2018-03-15.
+This document describes version 0.003 of Business::Inventory::Valuation (from Perl distribution Business-Inventory-Valuation), released on 2018-03-15.
 
 =head1 SYNOPSIS
 
